@@ -31,7 +31,7 @@
 Rawls <-
     function()
 {
-    access_token <- GCPtools::gcloud_access_token("rawls")
+    access_token <- gcloud_access_token("rawls")
     api_header <- c(Authorization = paste("Bearer", access_token))
     .Rawls(
         Service(
